<?php

/**
 * @file
 * Functions used by MM Media Assist
 */

/**
 * Print the main mm_media_assist category browser.
 */
function mm_media_assist_loader() {
  global $user;

  module_load_include('inc', 'monster_menus', 'mm_browser');
  $term_ids = func_get_args();
  $dashed = array_shift($term_ids);
  if ($dashed) {
    array_shift($term_ids);
    $start = array_pop($term_ids);
    mm_media_sanitize_termids($term_ids);
    if (count($term_ids)) {
      $top = $term_ids[0];
    }
    else {
      $dashed = explode('-', $dashed);
      $top = $dashed[0];
    }
    $output = mm_browser($start, $top, MM_BROWSER_MODE_GALLERY);
  }
  else {
    $location = $_GET['location'];
    $end = 0;
    if (stripos($location, '/node/') > 1) {
      $end = stripos($location, '/node/');
    }
    if (stripos($location, '/contents/') > 1) {
      $end = stripos($location, '/contents/');
    }
    $myterm_ids = array();
    if ($end) {
      $start = stripos($location, base_path()) + strlen(base_path());
      $url = substr($location, $start, $end - $start);
      monster_menus_url_inbound_alter($result, $url, NULL);
      mm_parse_args($myterm_ids, $oarg_list, $this_tid, $result);
    }
    $top_mmtid = isset($myterm_ids[0]) ? $myterm_ids[0] : 1;
    if (isset($this_tid) && is_numeric($this_tid))
      $output = mm_browser($this_tid, $top_mmtid, MM_BROWSER_MODE_MEDIA);
    else
      $output = mm_browser(mm_home_mmtid(), $top_mmtid, MM_BROWSER_MODE_MEDIA);
  }

  print theme('mm_media_assist_page',
    array(
      'content' => $output,
      'attributes' => array(
        'id' => 'mm-media-assist-load',
        'class' => array('mm-media-assist'),
      )
    )
  );
  $GLOBALS['devel_shutdown'] = FALSE; // prevent the devel module from outputting
  exit;
}

function mm_media_assist_upload($term_id) {
  if (($term_id = intval($term_id)) === 0) {
    drupal_access_denied();
  }

  if (array_key_exists('mm_media', node_get_types()) && node_access('create', 'mm_media')) {
    $output = drupal_get_form('mm_media_assist_node_form', $term_id);
  }

  print theme('mm_media_assist_page',
    array(
      'content' => $output,
      'attributes' => array(
        'id' => 'mm-media-assist-upload',
        'class' => array('mm-media-assist'),
      ),
    )
  );
  $GLOBALS['devel_shutdown'] = FALSE; // prevent the devel module from outputting
  exit;
}

function mm_media_assist_node_form($form, &$form_state, $term_id) {
  global $user;

  $node = array('uid' => $user->uid, 'name' => $user->name, 'type' => 'mm_media');
  module_load_include('inc', 'node', 'node.pages');
  drupal_add_css(drupal_get_path('module', 'mm_media') . '/mm_media_assist.css');

  $form = node_form($form, $form_state, $node);
  if ($term_id) {
    $tree = mm_content_get($term_id);
    $mmlist = array($term_id => mm_content_expand_name($tree->name));
    mm_content_get_default_node_perms($term_id, $grouplist, $userlist, MM_UI_MAX_USERS_IN_GROUP);
    $uid = $user->uid;
    $everyone = array_search(MM_PERMS_APPLY, explode(',', $tree->default_mode)) !== FALSE;
    $form['mm_categories'] = array(
      '#type' => 'fieldset',
      '#title' => t('Pages'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE
    );
    $form['mm_categories']['mm_catlist'] = array(
      '#type' => 'mm_catlist',
      '#description' => t('Choose additional pages where this content will appear.'),
      '#mm_list_popup_start' => implode('/', mm_content_get_parents($term_id)),
      '#default_value' => $mmlist
    );
    $form['mm_categories']['mm_catlist_restricted'] = array(
      '#type' => 'value',
      '#value' => array()
    );

    _mm_ui_node_form_perms($form, $userlist, $grouplist, $everyone,
      node_type_get_name($node), $uid,
      t('The default settings are taken from the settings of the page.'));
    $form['#validate'][] = 'mm_media_assist_node_form_validate';
    $form['#submit'][] = 'mm_media_assist_node_form_submit';
    unset($form['buttons']['preview']);
  }

  return $form;
}

function mm_media_assist_node_form_validate($form, &$form_state) {
  node_validate($form_state['values']);
}

function mm_media_assist_node_form_submit($form, &$form_state) {
  global $user;

  $node = node_submit($form_state['values']);
  if (node_access('create', $node)) {
    node_save($node);
    watchdog('content', '%type: added %title.', array('%type' => $node->type, '%title' => $node->title), WATCHDOG_NOTICE, l(t('view'), "node/$node->nid"));
    drupal_set_message(t('Your @post was created.', array('@post' => node_types_get_name($node))));
  }
  if (!empty($_COOKIE['mm_last_page'])) {
    // This is really not safe, but would not be very useful to exploit
    drupal_goto($_COOKIE['mm_last_page']);
  }
  drupal_goto('mm_media_assist/properties/' . $node->nid);
}

/**
 * Load the media properties pane
 */
function mm_media_assist_properties($node) {
  if (!mm_media_fetch_menu_access($node))
    drupal_access_denied();

  drupal_add_library('system', 'ui');

  $title = empty($node->title) ? $node->uploadedfilename : $node->title;
  $form[] = array('#markup' => '<div id="mm-media-assist"><div id="mm-media-assist-nav"><h2 class="mm-media-assist-title-nomenu">File Properties</h2></div>');

  $form_title = array(
    '#type' => 'textfield',
    '#title' => t('Title (optional)'),
    '#default_value' => $node->title,
    '#size' => 30,
    '#maxlength' => 255,
    '#description' => NULL,
  );
  $form_desc = array(
    '#type' => 'textfield',
    '#title' => t('Description (optional)'),
    '#default_value' => $node->body,
    '#size' => 30,
    '#maxlength' => 255,
    '#description' => NULL,
  );

  if ($node->isimage) {
    // Select (or generate) a preview image
    $properties_image = mm_media_display($node, MM_MEDIA_LABEL_STANDARD);

    // Create an array of image derivative choices
    $default_label = variable_get('mm_media_assist_default_label', MM_MEDIA_LABEL_STANDARD);
    foreach (_mm_media_image_get_sizes() as $size) {
      if ($size['label']) {
        $derivatives[$size['label']] = $size['label'];
      }
    }
    $derivatives[MM_MEDIA_LABEL_ORIGINAL] = MM_MEDIA_LABEL_ORIGINAL;

    // Create the form
    $form[] = array(
      '#markup' => '<div id="mm-media-assist-form" class="mm-media-assist-table"><p>' . t('Click "Insert" to embed this image in your text.') . '</p><p>' . t('The title won\'t show on screen but will be read by assistive devices for the blind.') . '</p>');

    $form['title'] = $form_title;
    $form['desc'] = $form_desc;

    // Size
    $form['size_label'] = array(
      '#title' => t('Size'),
      '#type' => 'select',
      '#default_value' => variable_get('mm_media_assist_default_label', MM_MEDIA_LABEL_STANDARD),
      '#options' => $derivatives,
    );

    // Settings
    $form[] = array('#markup' => '<div class="form-item" id="link-group">', '#title' => t('Settings'));
    $form['settings_node'] = array('#type' => 'checkbox', '#title' => t('Clicking on image shows it full-size'));
    $form['settings_outlined'] = array('#type' => 'checkbox', '#title' => t('Show a black border around the image'));
    $form['settings_margin'] = array('#type' => 'checkbox', '#title' => t('Include some empty space around the image'));
    $form[] = array('#markup' => '</div>');

    $form[] = array('#markup' => "</div><div id=\"mm-media-assist-preview\"><div class=\"mm-media-browse-imagesingle ui-state-default ui-widget-content\"><div class=\"ui-widget-header mm-media-browse-caption\">");
    $form[] = array('#markup' => t("@title - Preview</div>", array('@title' => $title)));
    $form[] = array('#markup' => $properties_image);
    $form[] = array('#markup' => "<br /><span id=\"caption\">{$node->title}</span>");
    $form[] = array('#markup' => "</div></div>\n");
  }   // end isimage
  else {
    $mm_media_player_audio_mimetypes = &drupal_static('mm_media_player_audio_mimetypes');
    $mm_media_player_video_mimetypes = &drupal_static('mm_media_player_video_mimetypes');
    $form[] = array(
      '#markup' => '<div id="mm-media-assist-form" class="mm-media-assist-table"><p>' . t('Click "Insert" to embed this file upload in your text.') . '</p><p>' . t('The title will appear next to the link to the file.') . '</p>');
    $properties_image = mm_media_display($node, MM_MEDIA_LABEL_ICON);
    $properties_size = isset($node->images[MM_MEDIA_LABEL_ICON]) ? image_get_info($node->images[MM_MEDIA_LABEL_ICON]) : 0; // get the actual size now

    $form['title'] = $form_title;
    $form['desc'] = $form_desc;

    if (in_array($node->filemime, $_mm_media_player_audio_mimetypes)) {
      $form['embed_into_node'] = array(
        '#type' => 'checkbox',
        '#default_value' => 0,
        '#title' => t('Show an in-line media player'),
        '#description' => NULL,
      );
    }

    if (in_array($node->filemime, $_mm_media_player_video_mimetypes)) {
      $form['previewimage'] = array(
        '#type' => 'textfield',
        '#size' => 45,
        '#maxlength' => 400,
        '#default_value' => '',
        '#title' => t('Full URL for the preview image (optional)'),
        '#description' => t('Provide node id for thumbnail e.g. https://www.amherst.edu/media/view/id#'),
      );
      $form['autostart'] = array(
        '#type' => 'checkbox',
        '#default_value' => 0,
        '#title' => t('Auto start movie'),
        '#description' => NULL,
      );
    }

    if ($node->filemime == 'application/x-shockwave-flash') {
      $form['menu'] = array(
        '#type' => 'checkbox',
        '#title' => t('Display full menu'),
        '#description' => NULL,
        '#prefix' => '<div class="container-inline">'
      );
      $form['loop'] = array(
        '#type' => 'checkbox',
        '#title' => t('Loop'),
        '#default_value' => 1,
        '#description' => NULL,
        '#suffix' => '</div>'
      );
      $form['play'] = array(
        '#type' => 'checkbox',
        '#default_value' => 1,
        '#title' => t('Auto play movie'),
        '#description' => NULL,
        '#prefix' => '<div class="container-inline">'
      );
      $form['swliveconnect'] = array(
        '#type' => 'checkbox',
        '#title' => t('SWLiveConnect'),
        '#suffix' => '</div>'
      );
      $form['quality'] = array(
        '#type' => 'select',
        '#title' => t('Quality'),
        '#options' => drupal_map_assoc(array('low', 'high', 'autolow', 'autohigh', 'best')),
        '#default_value' => 'high',
        '#prefix' => '<div class="container-inline">'
      );
      $form['scale'] = array(
        '#type' => 'select',
        '#title' => t('Scale'),
        '#options' => drupal_map_assoc(array('showall', 'border', 'exactfit')),
        '#default_value' => 'showall',
        '#suffix' => '</div>'
      );
      $form['wmode'] = array(
        '#type' => 'select',
        '#title' => t('WMode'),
        '#options' => drupal_map_assoc(array('window', 'opaque', 'transparent')),
        '#description' => t('Window mode property of the Flash movie'),
        '#default_value' => 'window',
      );
      $form['flashvars'] = array(
        '#type' => 'textfield',
        '#title' => t('Variables to pass to Flash player'),
        '#default_value' => '',
        '#size' => 48,
        '#maxlength' => 500,
        '#description' => NULL,
      );
      $form['base'] = array(
        '#type' => 'textfield',
        '#title' => t('Base URL used to resolve all relative path statements'),
        '#default_value' => '',
        '#size' => 48,
        '#maxlength' => 500,
        '#description' => NULL,
      );
    }
    if ($node->filemime == 'application/x-director') {
      $form['sound'] = array(
        '#type' => 'checkbox',
        '#title' => t('Sound'),
        '#default_value' => 1,
        '#description' => NULL,
        '#prefix' => '<div class="container-inline">'
      );
      $form['autostart'] = array(
        '#type' => 'checkbox',
        '#title' => t('Autostart'),
        '#default_value' => 1,
        '#description' => NULL,
        '#prefix' => '<span class="rightalign">',
        '#suffix' => '</span></div>'
      );
      $form['progress'] = array(
        '#type' => 'checkbox',
        '#title' => t('Progress'),
        '#description' => NULL,
        '#prefix' => '<div class="container-inline">'
      );
      $form['swliveconnect'] = array(
        '#type' => 'checkbox',
        '#title' => t('SWLiveConnect'),
        '#prefix' => '<span class="rightalign">',
        '#suffix' => '</span></div>'
      );
    }

    $form[] = array('#markup' => "</div><div id=\"mm-media-assist-preview\"><div class=\"mm-media-browse-imagesingle ui-state-default ui-widget-content\"><div class=\"ui-widget-header mm-media-browse-caption\">");
    $form[] = array('#markup' => t("@title - Preview</div>", array('@title' => $title)));
    $form[] = array('#markup' => $properties_image);
    $form[] = array('#markup' => "<br /><span id=\"caption\">{$node->title}</span>");
    $form[] = array('#markup' => "</div></div>\n");
  }
  // Hidden Fields
  $form['nid'] = array(
    '#type' => 'hidden',
    '#value' => $node->nid,
  );
  // Buttons
  $form['insert'] = array(
    '#type' => 'button',
    '#value' => t('Insert'),
    '#button_type' => 'button',
    '#prefix' => '</div><div class="mm-media-assist-buttons">',
  );
  $form['cancel'] = array(
    '#type' => 'button',
    '#value' => t('Back'),
    '#button_type' => 'button',
  );
  $form['abort'] = array(
    '#type' => 'button',
    '#value' => t('Close window'),
    '#button_type' => 'button',
    '#suffix' => '</div>',
  );

  $form['#attributes'] = array('name' => 'mm_media_assist', 'class' => array('mm-media-assist'));
  $form['#post'] = $_POST;
  $form['#programmed'] = FALSE;
  $form['#tree'] = FALSE;
  $my_form_state = array('storage' => NULL, 'submitted' => FALSE);
  drupal_process_form('mm_media_assist_properties', $form, $my_form_state);
  $output = drupal_render($form);
  print theme('mm_media_assist_page',
    array(
      'content' => $output,
      'attributes' => array(
        'id' => 'mm-media-assist-properties',
        'class' => array('mm-media-assist'),
      )
    )
  );
  $GLOBALS['devel_shutdown'] = FALSE; // prevent the devel module from outputting
  exit;
}

/********************************************************************
 * Module Functions :: Image Generation
 ********************************************************************/

/**
 * Return image HTML.
 */
function mm_media_assist_insert_html() {
  global $user;
  $mm_media_player_audio_mimetypes = &drupal_static('mm_media_player_audio_mimetypes');
  $mm_media_player_video_mimetypes = &drupal_static('mm_media_player_video_mimetypes');

  $attributes_str = $_POST['inserthtml'];
  $attributes = array();
  $key_vals = explode('|', $attributes_str);
  foreach ($key_vals as $keyval) {
    $arr = explode('=', $keyval);
    $attributes[urldecode($arr[0])] = isset($arr[1]) ? urldecode($arr[1]) : '';
  }

  $finalhtmlcode = '';
  if (!empty($attributes['nid'])) {
    $node = node_load(array('nid' => $attributes['nid']));
    if (!mm_media_fetch_menu_access($node))
      drupal_access_denied();
    if ($node->filemime == 'application/x-director') {
      $info = image_get_info($node->images[MM_MEDIA_LABEL_ORIGINAL]);
      $attributes['height'] = $info['height'];
      $attributes['width'] = $info['width'];
      $attributes['sound'] = empty($attributes['sound']) ? 'false' : 'true';
      $attributes['progress'] = empty($attributes['progress']) ? 'false' : 'true';
      $attributes['autostart'] = empty($attributes['autostart']) ? 'false' : 'true';
      $attributes['swliveconnect'] = empty($attributes['swliveconnect']) ? 'false' : 'true';
      $shockwave_attr = array('width', 'height', 'swliveconnect', 'sound', 'progress', 'autostart');
      $shockwave_str = _mm_media_assist_writeEmbed($attributes, $shockwave_attr) . "src:'" . _mm_media_get_url($node, MM_MEDIA_LABEL_ORIGINAL) . "'";
      $finalhtmlcode = '<img class="mceItemShockWave" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" src="' . base_path() . drupal_get_path('module', 'mm_media') . '/icons/spacer.gif' . '" title="' . $shockwave_str . '" _moz_resizing="true" />';
    }
    elseif (in_array($node->filemime, $_mm_media_player_audio_mimetypes) && isset($attributes['embed_into_node']) && $attributes['embed_into_node'] == 1) {
      $width = variable_get('mm_media_assist_audio_width', 400);
      $height = variable_get('mm_media_assist_audio_height', 21);
      $finalhtmlcode = '<div class="mm-media-flvplay" style="width:' . $width . 'px; height:' . $height . 'px;">' .
      '<swf width="' . $width . '" height="' . $height . '" ' .
        'file="' . url('mm_media/view/' . $node->nid . '/original/' . urlencode($node->uploadedfilename), array('absolute' => TRUE)) .
        '"></div>';
    }
    elseif (in_array($node->filemime, $_mm_media_player_video_mimetypes)) {
      $info = $node->fileattribs;
      $flashvars = empty($attributes['autostart']) ? 'flashvars="autostart=false' : 'flashvars="autostart=true';
      $flashvars .= !empty($attributes['previewimage']) ? '&&image=' . $attributes['previewimage'] . '"' : '&&image=' . variable_get('mm_media_assist_preview_image', '') . '"';
      $finalhtmlcode = '<div class="mm-media-flvplay" style="width:' . $info['width'] . 'px; height:' . $info['height'] . 'px;">' .
          '<swf ' . $flashvars . ' width="' . $info['width'] .
          '" height="' . $info['height'] . '" ' .
          'file="' . url('mm_media/view/' . $node->nid . '/original/' . urlencode($node->uploadedfilename), array('absolute' => TRUE)) .
          '"></div>';
    }
    elseif ($node->filemime == 'application/x-shockwave-flash') {
      $info = image_get_info($node->images[MM_MEDIA_LABEL_ORIGINAL]);
      $attributes['height'] = $info['height'];
      $attributes['width'] = $info['width'];
      $attributes['menu'] = empty($attributes['menu']) ? 'false' : 'true';
      $attributes['play'] = empty($attributes['play']) ? 'false' : 'true';
      $attributes['loop'] = empty($attributes['loop']) ? 'false' : 'true';
      $attributes['swliveconnect'] = empty($attributes['swliveconnect']) ? 'false' : 'true';
      $flash_attr = array('width', 'height', 'swliveconnect', 'src', 'play', 'loop',
                          'menu', 'quality', 'scale', 'align', 'wmode', 'base', 'flashvars');
      $flash_str = _mm_media_assist_writeEmbed($attributes, $flash_attr) . "src:'" . _mm_media_get_url($node, MM_MEDIA_LABEL_ORIGINAL) . "'";
      $finalhtmlcode = '<img class="mceItemFlash" width="' . $attributes['width'] .
        '" height="' . $attributes['height'] .
        '" src="' . base_path() . drupal_get_path('module', 'mm_media') . '/icons/spacer.gif' . '"  title="' . $flash_str . '" _moz_resizing="true" />';
    }
    elseif (!$node->isimage) {
      $finalhtmlcode = theme('mm_media_assist_inline', array('node' => $node, 'attributes' => $attributes));
    }
    else {
      $finalhtmlcode = theme('mm_media_assist_inline', array('node' => $node, 'label' => $attributes['size_label'], 'attributes' => $attributes));
    }
  }

  print '<div id="finalhtmlcode">' . $finalhtmlcode . '</div>';
  $GLOBALS['devel_shutdown'] = FALSE; // prevent the devel module from outputting
  exit;
}

// --------------------------------------------------------------------------------
// Theme Functions
// --------------------------------------------------------------------------------

/**
 * Theme the inline media assist inline
 *
 * @param $variables
 *   An associative array containing:
 *   - node: the selected node
 *   - label: the label of the size, e.g. standard, original, thumbnail
 *   - attributes: any attributes
 *
 * @ingroup themeable
 */
function theme_mm_media_assist_inline($variables) {
  $node = $variables['node'];
  $label = $variables['label'];
  $attributes = $variables['attributes'];

  $caption = '';
  if (!empty($attributes['title'])) {
    $caption = $attributes['title'];
  }
  $node->title = strip_tags($caption);
  $align = '';
  if (!empty($attributes['align'])) $align = ' ' . $attributes['align'];
  $output = "<div class=\"mm-mediainline\"><span class=\"inline$align\">";

  $class = array();
  if (!$node->isimage) $class[] = 'image-stock';
  else {
    if (isset($attributes['settings_outlined']) && $attributes['settings_outlined'] === '1') $class[] = 'image-border';
    if (isset($attributes['settings_margin']) && $attributes['settings_margin'] === '1') $class[] = 'image-margin';
  }
  $atts = array();
  if (is_array($class)) $atts['class'] = join(' ', $class);
  if (!empty($attributes['desc'])) $atts['desc'] = $attributes['desc'];

  $img_tag = mm_media_display($node, $label, $atts);

  if ($node->isimage) {
    if (isset($attributes['settings_node']) && $attributes['settings_node'] === '1') {
      $tids = mm_content_get_by_nid($node->nid);
      if ($tids) {
        $url = mm_content_get_mmtid_url($tids[0]);
        $output .= l($img_tag, $url . '/node/' . $node->nid . '/original/' . $node->uploadedfilename, array('html' => TRUE));
      }
      else
        $output .= $img_tag;
    }
    else
      $output .= $img_tag;
  }
  else {
    $output .= l($img_tag, 'mm_media/view/' . $node->nid . '/original/' . $node->uploadedfilename, array('html' => TRUE));
    if ($caption)
      $output .= l(mm_ui_hide_node_title($caption), 'mm_media/view/' . $node->nid . '/original/' . $node->uploadedfilename, array('html' => TRUE));
  }

  $output .= '</span></div>';
  return $output;
}

/**
 * Theme the media assist page
 *
 * @param $variables
 *   An associative array containing:
 *   - content: the selected node
 *   - attributes: any attributes
 *
 * @ingroup themeable
 */
function theme_mm_media_assist_page($variables) {
  drupal_add_css(drupal_get_path('module', 'mm_media') . '/mm_media_assist.css');
  _mm_media_assist_add_custom_js();
  return theme('mm_page_wrapper',
    array(
      'title' => t('Select a file upload'),
      'body' => $variables['content'],
      'wrap_body_with_div' => FALSE,
      'attributes' => $variables['attributes']
    )
  );
}

/* embed helper functions */
function _mm_media_assist_writeEmbed($p, $attr_names) {
  $h = '';
  foreach ($p as $key => $val)
    if (array_search($key, $attr_names) !== FALSE)
      $h .= "$key:'$val', ";
  return $h;
}

function _mm_media_get_url($node, $label) {
  return url('mm_media/view/' . $node->nid . '/' . $label . '/' . $node->uploadedfilename);
}

function _mm_media_assist_add_custom_js() {
  $error = t('The media cannot be inserted because the page that opened the popup is no longer present.');
  drupal_add_js(mm_static('back_in_history') . '
(function (\$) {

Drupal.mmMediaUpdateCaption = function() {
  var title = $("input[name=title]").val();
  var desc = $("input[name=desc]").val();
  if (desc) title += ":";
  $("#caption").html("<strong>" + title + "</strong> " + desc);
};

Drupal.mmMediaInsertImage = function() {
  if (window.opener) {
    // Get variables from the fields on the properties frame
    var str = "";
    $(":input").each(function() {
      if ($(this).attr("type") != "checkbox") str = str + $(this).attr("name") + "=" + encodeURIComponent($(this).val()) + "|";
      else if ($(this).attr("checked")) str = str + $(this).attr("name") + "=" + encodeURIComponent($(this).val()) + "|";
    });
    jQuery.post(Drupal.settings.basePath + "mm_media_assist/insert_html/",
      { inserthtml: str },
      function(data) {
        $("#caption")
          .hide()
          .html(data);
        window.opener.tinyMCE.execCommand("mceInsertContent", false, $("#finalhtmlcode").html());
        window.opener.tinyMCE.execCommand("mceRepaint");
        window.close();
      }
    );
  }
  else {
    alert("' . $error . '");
    return false;
  }
};

Drupal.behaviors.mmMediaInit = {
  attach: function (context, settings) {
    $(".mm-media-assist-table", context).once("mm-media-assist-table", function () {
      $("input[name=title],input[name=desc]")
        .blur(Drupal.mmMediaUpdateCaption);
      $("input#edit-abort")
        .click(function() {window.close();});
      $("input#edit-cancel")
        .click(function() {Drupal.mm_back_in_history();});
      $("input#edit-insert")
        .click(Drupal.mmMediaInsertImage);
    });
  }
};
})(jQuery);', 'inline');
}
